#!/bin/bash
#SBATCH --account=project_465001141
#SBATCH --partition=small
#SBATCH --ntasks=4
#SBATCH --time=03:00:00

set -o errexit -o nounset -o xtrace

# Set path to HDF filters used for compression
export HDF5_PLUGIN_PATH='/appl/local/climatedt/sw/netcdf-plugins/'

# Pre-computed remapping weights (ICON > HEALPix)
weightsdir='/appl/local/climatedt/pool/data/ICON/healpix_weights/weights'

src_grid="R02B10"
tgt_grid="hpz9"

# Define file and directory names
infile=$1
outdir=$(dirname $infile)/healpix
outfile=${outdir}/$(basename $infile)
outfile_part=${outdir}/$(basename $infile).partial

mkdir -p $outdir

# Choose ocean/atmosphere remapping weights
if [[ $infile == *oce* ]]; then
    weightsfile="$weightsdir/weights_${src_grid}_O_${tgt_grid}.nc"
else
    weightsfile="$weightsdir/weights_${src_grid}_G_${tgt_grid}.nc"
fi

if [ ! -f $outfile ]; then
  # Remap, chunk, and compress the given input file
  cdo \
    --format nc4 \
    --compression_type zstd \
    --chunktype auto \
    --chunksize $((4**9)) \
    --num_threads 4 \
    -remap,$tgt_grid,$weightsfile \
    $infile $outfile_part

  ncrename -d cells,cell $outfile_part
  mv $outfile_part $outfile
fi
